power_cogs.trainer package — power_cogs 0.1.0 documentation

# power_cogs.trainer package

## Submodules

## power_cogs.trainer.mnist_trainer module

class `power_cogs.trainer.mnist_trainer.` `MNISTTrainer`(name: Optional[str] = None, pretrained_path: Optional[str] = None, visualize_output: bool = False, use_cuda: bool = False, device_id: int = 0, early_stoppage: bool = False, loss_threshold: float = -inf, batch_size: int = 32, epochs: int = 100, checkpoint_interval: int = 100, num_samples: Optional[int] = None, model_config: Dict[str, Any] = {}, dataset_config: Dict[str, Any] = {}, optimizer_config: Dict[str, Any] = {}, scheduler_config: Dict[str, Any] = {}, logging_config: Dict[str, Any] = {}, dataloader_config: Dict[str, Any] = {}, tune_config: Dict[str, Any] = {}, config: Dict[str, Any] = {})

  Bases: `power_cogs.base.base_torch_trainer.BaseTorchTrainer`

  `post_dataset_setup`()
  `train_iter`(batch_size: int = 32, iteration: int = 0)

    Training iteration, specify learning process here

## Module contents